/*
 * Copyright (C) 2005 Johan Maasing johan at zoom.nu Licensed under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package nu.zoom.swing.desktop.plugin.portunis.impl;

import java.awt.event.ActionEvent;
import java.io.File;

import javax.swing.Action;

import org.ops4j.gaderian.Messages;

import nu.zoom.swing.desktop.common.action.WorkbenchMessageAction;
import nu.zoom.swing.desktop.plugin.portunis.KeyStoreWrapper;

/**
 * An action to open and display a keystore.
 * 
 * @version $Revision: 1.1 $
 * @author $Author: johan $
 */
public class DisplayKeyStoreAction extends WorkbenchMessageAction {

    private KeyStorePlugIn keyStorePlugIn;
    private KeyStoreWrapper wrapper;

    public DisplayKeyStoreAction(KeyStorePlugIn keyStorePlugIn,
            Messages messages, KeyStoreWrapper wrapper) {
        super(messages);
        this.wrapper = wrapper;
        this.keyStorePlugIn = keyStorePlugIn;
        File storeFile = wrapper.getFile();
        String storeName;
        String tooltip;
        if (storeFile != null) {
            storeName = storeFile.getName();
            tooltip = storeFile.getAbsolutePath();
        } else {
            storeName = messages.getMessage("keystore.noname");
            tooltip = messages.getMessage("keystore.noname.tooltip");
        }
        putValue(Action.NAME, storeName);
        putValue(Action.SHORT_DESCRIPTION, tooltip);
        setIconFromMessages("keystore.load.loaded.icon");
    }

    /*
     * (non-Javadoc)
     *
     * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        keyStorePlugIn.displayKeyStore(wrapper);
    }
}
